# 6.6.0

With more than 160 pull requests from 14 contributors, this release brings improved support for using OpenLayers in Node.js enviromnents, a new WKB (well knowm binary) format, TypeScript declarations in the ol package, and more efficient vector tile rendering. In addition, several examples were added or improved, and many bugs were fixed.

## Upgrade notes

#### Included TypeScript declarations

The [ol package](https://npmjs.com/package/ol) now includes TypeScript declarations as `*.d.ts` files.

If desired, e.g. when you don't want to adjust your code after upgrading from a previous version where you used `@types/ol`, you can opt out of the included types and use third-party types by specifying aliases in the `compilerOptions` section of `tsconfig.json`, e.g.
```json
    "baseUrl": "./",
    "paths": {
      "ol": ["node_modules/@types/ol"],
      "ol/*": ["node_modules/@types/ol/*"]
    },
```
#### Deprecation of `undefinedHTML` option for the MousePosition control

The `undefinedHTML` option for the MousePosition control has been deprecated and will be removed in a future release.  Use the new `placeholder` option instead.

#### New `placeholder` option for the MousePosition control

When the mouse position is not available, the control renders a non-breaking space.  To render somthing else instead,
set the `placeholder` option.  If you want to retain the last position when the mouse leaves the viewport, set
`placeholder: false`.  This will be the default behavior in a future release.

The `placeholder` option has no effect if the deprecated `undefinedHTML` option is also used.  You should use the `placeholder` option instead of `undefinedHTML`.

#### Deprecation of `image` render mode for vector tile layers

`renderMode: 'image'` for vector tile layers has been deprecated. Applications continue to work, but a warning will be issued to the console. To get rid of the warning, simply remove the `renderMode` option.

## New features and improvements

 * New [create-ol-app](https://www.npmjs.com/package/create-ol-app) package to create a new app with an OpenLayers map.
 * Improved rendering quality of regular shapes and circles.
 * New `placeholder` option for better control of the `MousePosition` control's output.
 * TypeScript generated `.d.ts` files are now included in the [ol](https://npmjs.com/package/ol) package.
 * Improved `zDirection` option on tile sources to control when the tile z changes on fractional zoom levels.
 * Template mode for the `TileDebug` source for better debugging of tile coordinate issues.
 * More efficient vector tile rendering to save battery on mobile devices and memory.
 * New 'properties' option on layers for easier use of arbitrary properties in typed environments.
 * Hit detection support when using OffscreenCanvas and workers for rendering.
 * The [ol](https://npmjs.com/package/ol) now uses `"type": "module"` in `package.json` for easier use of OpenLayers in Node.js.
 * New WKB (Well-Known Binary) format parser and serializer.
 * Console warning when map container's width or height are zero.
 * New `snapToPointer` option on the `Modify` interaction to control user experience when clicking a vertex far away from its center.


## List of all changes
 * [#12442](https://github.com/openlayers/openlayers/pull/12442) - Fix layer render extent when it is not at all in view ([@MoonE](https://github.com/MoonE))
 * [#12492](https://github.com/openlayers/openlayers/pull/12492) - Use create-ol-app to create a new app ([@tschaub](https://github.com/tschaub))
 * [#12467](https://github.com/openlayers/openlayers/pull/12467) - Fixes / improvements for RegularShape ([@MoonE](https://github.com/MoonE))
 * [#12491](https://github.com/openlayers/openlayers/pull/12491) - Add a new placeholder option and deprecate undefinedHTML for the mouse position control ([@tschaub](https://github.com/tschaub))
 * [#12430](https://github.com/openlayers/openlayers/pull/12430) - Event listener typing ([@simonseyock](https://github.com/simonseyock))
 * [#12488](https://github.com/openlayers/openlayers/pull/12488) - MousePosition: allow rendering of empty string ([@JakobMiksch](https://github.com/JakobMiksch))
 * [#12464](https://github.com/openlayers/openlayers/pull/12464) - Make zDirection option available for all tile sources ([@mike-000](https://github.com/mike-000))
 * [#12489](https://github.com/openlayers/openlayers/pull/12489) - Update ol-mapbox-style to v6.4.0 ([@ahocevar](https://github.com/ahocevar))
 * [#12484](https://github.com/openlayers/openlayers/pull/12484) - Add GeoSolutions as a monthly sponsor ([@tschaub](https://github.com/tschaub))
 * [#12480](https://github.com/openlayers/openlayers/pull/12480) - Fix gap in tiles due to floating point math ([@MoonE](https://github.com/MoonE))
 * [#12453](https://github.com/openlayers/openlayers/pull/12453) - Allow multiple LinearRings per innerBoundaryIs ([@MoonE](https://github.com/MoonE))
 * [#12466](https://github.com/openlayers/openlayers/pull/12466) - Fix getVectorContext on TileLayer with pixelRatio != 1 ([@MoonE](https://github.com/MoonE))
 * [#12463](https://github.com/openlayers/openlayers/pull/12463) - Improve animation examples ([@MoonE](https://github.com/MoonE))
 * [#12459](https://github.com/openlayers/openlayers/pull/12459) - Fix documentation for GML class. ([@simonseyock](https://github.com/simonseyock))
 * [#12455](https://github.com/openlayers/openlayers/pull/12455) - Consistent use of quotes in example description ([@mike-000](https://github.com/mike-000))
 * [#12373](https://github.com/openlayers/openlayers/pull/12373) - Rework TileDebug to allow TMS coordinates and to fix reprojection ([@mike-000](https://github.com/mike-000))
 * [#12441](https://github.com/openlayers/openlayers/pull/12441) - Style-based measure example ([@mike-000](https://github.com/mike-000))
 * [#12438](https://github.com/openlayers/openlayers/pull/12438) - typo ([@jipexu](https://github.com/jipexu))
 * [#12431](https://github.com/openlayers/openlayers/pull/12431) - Add tsc-generated type definitions for opt-in ([@ahocevar](https://github.com/ahocevar))
 * [#12417](https://github.com/openlayers/openlayers/pull/12417) - Use html2canvas instead of dom-to-image ([@ahocevar](https://github.com/ahocevar))
 * [#12413](https://github.com/openlayers/openlayers/pull/12413) - Fix hitdetection image invalidation ([@MoonE](https://github.com/MoonE))
 * [#12405](https://github.com/openlayers/openlayers/pull/12405) - VectorTile getSourceTiles behaviour with loading source tiles ([@ahocevar](https://github.com/ahocevar))
 * [#12212](https://github.com/openlayers/openlayers/pull/12212) - Ignore empty gx:coord elements in KML files ([@voegelas](https://github.com/voegelas))
 * [#12418](https://github.com/openlayers/openlayers/pull/12418) - Fix icon tinting with pixelRatio < 1 ([@MoonE](https://github.com/MoonE))
 * [#12409](https://github.com/openlayers/openlayers/pull/12409) - Fix WMTS wrapX detection if WGS84BoundingBox is not set ([@M393](https://github.com/M393))
 * [#12237](https://github.com/openlayers/openlayers/pull/12237) - Fix Modify interaction with hitDetection ([@M393](https://github.com/M393))
 * [#12416](https://github.com/openlayers/openlayers/pull/12416) - Use generics to limit event types in on(), once() and un() ([@ahocevar](https://github.com/ahocevar))
 * [#12408](https://github.com/openlayers/openlayers/pull/12408) - Do not fire modifystart when nothing is being modified ([@ahocevar](https://github.com/ahocevar))
 * [#12414](https://github.com/openlayers/openlayers/pull/12414) - Replace getChangeEventType() with add/removeChangeListener methods ([@ahocevar](https://github.com/ahocevar))
 * [#12194](https://github.com/openlayers/openlayers/pull/12194) - Respect pixel ratio with immediate render ([@MoonE](https://github.com/MoonE))
 * [#12298](https://github.com/openlayers/openlayers/pull/12298) - Fix JSDoc generated links ([@tschaub](https://github.com/tschaub))
 * [#12231](https://github.com/openlayers/openlayers/pull/12231) - Move tolerance should not increase with higher pixel ratio ([@MoonE](https://github.com/MoonE))
 * [#12282](https://github.com/openlayers/openlayers/pull/12282) - Fix DragZoom with view padding ([@M393](https://github.com/M393))
 * [#12223](https://github.com/openlayers/openlayers/pull/12223) - generic source parameters for options ([@simonseyock](https://github.com/simonseyock))
 * [#12219](https://github.com/openlayers/openlayers/pull/12219) - Add 'properties' to Layer constructors ([@ahocevar](https://github.com/ahocevar))
 * [#12284](https://github.com/openlayers/openlayers/pull/12284) - Layers should inherit group z-index ([@MoonE](https://github.com/MoonE))
 * [#12304](https://github.com/openlayers/openlayers/pull/12304) - New example: Scale and Rotate using Modify Interaction ([@mike-000](https://github.com/mike-000))
 * [#12378](https://github.com/openlayers/openlayers/pull/12378) - Correct .split() calls to only split numeric srid for ArcgisRest ([@mike-000](https://github.com/mike-000))
 * [#12393](https://github.com/openlayers/openlayers/pull/12393) - Scale up static Image and round to nearest pixel to avoid rounding errors ([@mike-000](https://github.com/mike-000))
 * [#12394](https://github.com/openlayers/openlayers/pull/12394) - Ensure VectorSource getUrl() corresponds to last setUrl() ([@mike-000](https://github.com/mike-000))
 * [#12357](https://github.com/openlayers/openlayers/pull/12357) - Use calculateElevation function in Shaded Relief example ([@mike-000](https://github.com/mike-000))
 * [#12375](https://github.com/openlayers/openlayers/pull/12375) - Fix Vector Tile Selection example on old browsers ([@mike-000](https://github.com/mike-000))
 * [#12364](https://github.com/openlayers/openlayers/pull/12364) - Simpler and faster VectorTile loading ([@ahocevar](https://github.com/ahocevar))
 * [#12359](https://github.com/openlayers/openlayers/pull/12359) - Fix broken link in docs ([@mike-000](https://github.com/mike-000))
 * [#12330](https://github.com/openlayers/openlayers/pull/12330) - Do not require PointerEvent constructor ([@ahocevar](https://github.com/ahocevar))
 * [#12355](https://github.com/openlayers/openlayers/pull/12355) - document descending order of resolutions array ([@simonseyock](https://github.com/simonseyock))
 * [#12349](https://github.com/openlayers/openlayers/pull/12349) - Document the input to an attribution function ([@mike-000](https://github.com/mike-000))
 * [#12340](https://github.com/openlayers/openlayers/pull/12340) - Fix raster example tooltips ([@MoonE](https://github.com/MoonE))
 * [#12338](https://github.com/openlayers/openlayers/pull/12338) - Do not use __proto__ to restore instances after main thread - worker transfer ([@ahocevar](https://github.com/ahocevar))
 * [#12339](https://github.com/openlayers/openlayers/pull/12339) - Fix confusing import in Mapbox Style example ([@mike-000](https://github.com/mike-000))
 * [#12306](https://github.com/openlayers/openlayers/pull/12306) - Fix layer canvas reuse ([@M393](https://github.com/M393))
 * [#12334](https://github.com/openlayers/openlayers/pull/12334) - More consistent example for ol/layer/MapboxVector ([@MoonE](https://github.com/MoonE))
 * [#12315](https://github.com/openlayers/openlayers/pull/12315) - Improve attribution accessibility ([@MoonE](https://github.com/MoonE))
 * [#12313](https://github.com/openlayers/openlayers/pull/12313) - Hitdetection offscreencanvas worker ([@vittrup88](https://github.com/vittrup88))
 * [#12297](https://github.com/openlayers/openlayers/pull/12297) - Add condition option to Translate interaction ([@mike-000](https://github.com/mike-000))
 * [#12283](https://github.com/openlayers/openlayers/pull/12283) - Add link to yey'maps as a sponsor ([@tschaub](https://github.com/tschaub))
 * [#12277](https://github.com/openlayers/openlayers/pull/12277) - Lint the index file after generating the legacy build ([@tschaub](https://github.com/tschaub))
 * [#12266](https://github.com/openlayers/openlayers/pull/12266) - Fix legacy build ([@MoonE](https://github.com/MoonE))
 * [#12273](https://github.com/openlayers/openlayers/pull/12273) - Use lowercase module names for modules without a default export ([@tschaub](https://github.com/tschaub))
 * [#12264](https://github.com/openlayers/openlayers/pull/12264) - Run selected format tests in Node ([@tschaub](https://github.com/tschaub))
 * [#12263](https://github.com/openlayers/openlayers/pull/12263) - Fix the next-dev-version.js script ([@tschaub](https://github.com/tschaub))
 * [#12241](https://github.com/openlayers/openlayers/pull/12241) - Use modules everywhere ([@tschaub](https://github.com/tschaub))
 * [#12250](https://github.com/openlayers/openlayers/pull/12250) - Do not set projection extent in WMTS optionsFromCapabilities ([@mike-000](https://github.com/mike-000))
 * [#12259](https://github.com/openlayers/openlayers/pull/12259) - Make it clearer what fails in webgl point layer test ([@tschaub](https://github.com/tschaub))
 * [#12258](https://github.com/openlayers/openlayers/pull/12258) - Following the recommendation to run on a merge commit ([@tschaub](https://github.com/tschaub))
 * [#12251](https://github.com/openlayers/openlayers/pull/12251) - Test reorganization ([@tschaub](https://github.com/tschaub))
 * [#12249](https://github.com/openlayers/openlayers/pull/12249) - Update the name of the build job ([@tschaub](https://github.com/tschaub))
 * [#12248](https://github.com/openlayers/openlayers/pull/12248) - Avoid naming required checks with a changing version ([@tschaub](https://github.com/tschaub))
 * [#12238](https://github.com/openlayers/openlayers/pull/12238) - Use proxy url as interim fix for mixed content in the MapGuide example ([@mike-000](https://github.com/mike-000))
 * [#12239](https://github.com/openlayers/openlayers/pull/12239) - Add example showing how to Draw and Modify geodesic circles ([@mike-000](https://github.com/mike-000))
 * [#12247](https://github.com/openlayers/openlayers/pull/12247) - Build on Node 16 and update dev dependencies ([@tschaub](https://github.com/tschaub))
 * [#12230](https://github.com/openlayers/openlayers/pull/12230) - Fix @types/estree version and remove skipLibCheck: false from tsconfig ([@ahocevar](https://github.com/ahocevar))
 * [#11952](https://github.com/openlayers/openlayers/pull/11952) - Draw 800km circles around both poles in Tissot example ([@mike-000](https://github.com/mike-000))
 * [#12229](https://github.com/openlayers/openlayers/pull/12229) - Prevent TypeScript Compiler from erroring out due to lib checks ([@ahocevar](https://github.com/ahocevar))
 * [#12224](https://github.com/openlayers/openlayers/pull/12224) - Use a better maintained loader for test coverage ([@ahocevar](https://github.com/ahocevar))
 * [#12227](https://github.com/openlayers/openlayers/pull/12227) - Fix event handling for map in shadow root ([@MoonE](https://github.com/MoonE))
 * [#12214](https://github.com/openlayers/openlayers/pull/12214) - Do not set invalid style ([@ahocevar](https://github.com/ahocevar))
 * [#12216](https://github.com/openlayers/openlayers/pull/12216) - Fix ZoomSlider layout ([@MoonE](https://github.com/MoonE))
 * [#12217](https://github.com/openlayers/openlayers/pull/12217) - Fix building of examples with latest copy-webpack-plugin ([@MoonE](https://github.com/MoonE))
 * [#12198](https://github.com/openlayers/openlayers/pull/12198) - Add attributionsCollapsible option to source/TileWMS and source/WMTS ([@sbx320](https://github.com/sbx320))
 * [#12176](https://github.com/openlayers/openlayers/pull/12176) - Allow private class members to be mangled ([@bz2](https://github.com/bz2))
 * [#12178](https://github.com/openlayers/openlayers/pull/12178) - Add WKB (Well-Known Binary) format ([@kikuchan](https://github.com/kikuchan))
 * [#12180](https://github.com/openlayers/openlayers/pull/12180) - Fix rendering of MultiPolygon text styles ([@MoonE](https://github.com/MoonE))
 * [#12185](https://github.com/openlayers/openlayers/pull/12185) - MapBrowserEvent#preventDefault() behaves the same as with native events ([@ahocevar](https://github.com/ahocevar))
 * [#12181](https://github.com/openlayers/openlayers/pull/12181) - Build for ie11 again ([@MoonE](https://github.com/MoonE))
 * [#12028](https://github.com/openlayers/openlayers/pull/12028) - Overview map no initial target ([@MoonE](https://github.com/MoonE))
 * [#12175](https://github.com/openlayers/openlayers/pull/12175) - Refresh available examples before each compilation ([@MoonE](https://github.com/MoonE))
 * [#12172](https://github.com/openlayers/openlayers/pull/12172) - Fix icon displacement ([@ahocevar](https://github.com/ahocevar))
 * [#12170](https://github.com/openlayers/openlayers/pull/12170) - Link to GitHub sponsors page ([@tschaub](https://github.com/tschaub))
 * [#12168](https://github.com/openlayers/openlayers/pull/12168) - VectorSource#getFeatures() consistently returns a new array ([@ahocevar](https://github.com/ahocevar))
 * [#12164](https://github.com/openlayers/openlayers/pull/12164) - Fix offscreen-canvas example ([@ahocevar](https://github.com/ahocevar))
 * [#12163](https://github.com/openlayers/openlayers/pull/12163) - Fix how renderMode is derived from options ([@ahocevar](https://github.com/ahocevar))
 * [#12137](https://github.com/openlayers/openlayers/pull/12137) - Load less tiles when low on frame budget ([@ahocevar](https://github.com/ahocevar))
 * [#12143](https://github.com/openlayers/openlayers/pull/12143) - Fix singleclick and doubleclick events ([@ahocevar](https://github.com/ahocevar))
 * [#12141](https://github.com/openlayers/openlayers/pull/12141) - call the success callback after the features are added ([@kikitte](https://github.com/kikitte))
 * [#12135](https://github.com/openlayers/openlayers/pull/12135) - Update webpack ([@tschaub](https://github.com/tschaub))
 * [#11405](https://github.com/openlayers/openlayers/pull/11405) - Fixes extent calculation in WMTS optionsFromCapabilities when BoundingBox exists ([@amir-ba](https://github.com/amir-ba))
 * [#12128](https://github.com/openlayers/openlayers/pull/12128) - Package lockfile version update ([@tschaub](https://github.com/tschaub))
 * [#12102](https://github.com/openlayers/openlayers/pull/12102) - Update eslint-config-openlayers ([@simonseyock](https://github.com/simonseyock))
 * [#12089](https://github.com/openlayers/openlayers/pull/12089) - Fix common misspellings ([@marcjansen](https://github.com/marcjansen))
 * [#12062](https://github.com/openlayers/openlayers/pull/12062) - Fix kml-timezone example tooltip ([@M393](https://github.com/M393))
 * [#12088](https://github.com/openlayers/openlayers/pull/12088) - Fix broken url/description of ImageArcGISRest documentation ([@dbretschneider](https://github.com/dbretschneider))
 * [#12083](https://github.com/openlayers/openlayers/pull/12083) - Simplify event handling for custom elements ([@ahocevar](https://github.com/ahocevar))
 * [#12080](https://github.com/openlayers/openlayers/pull/12080) - Add a minimum distance config to the cluster source ([@MoonE](https://github.com/MoonE))
 * [#12084](https://github.com/openlayers/openlayers/pull/12084) - Only preventDefault when event is cancelable ([@ahocevar](https://github.com/ahocevar))
 * [#12079](https://github.com/openlayers/openlayers/pull/12079) - Change IGN WMTS example to use PLANIGNV2 layer ([@mike-000](https://github.com/mike-000))
 * [#12016](https://github.com/openlayers/openlayers/pull/12016) - Fix VectorLayer hitdetect problems ([@MoonE](https://github.com/MoonE))
 * [#11845](https://github.com/openlayers/openlayers/pull/11845) - Call finishCondition for all types for Draw interaction ([@MoonE](https://github.com/MoonE))
 * [#12066](https://github.com/openlayers/openlayers/pull/12066) - Always return Promise from getFeatures ([@M393](https://github.com/M393))
 * [#12057](https://github.com/openlayers/openlayers/pull/12057) - TileQueue tests with events instead of setTimeout ([@ahocevar](https://github.com/ahocevar))
 * [#12058](https://github.com/openlayers/openlayers/pull/12058) - Fix map loading for basemap.at and add attributions ([@M393](https://github.com/M393))
 * [#12024](https://github.com/openlayers/openlayers/pull/12024) - Add a tile grid method for getting a tile range given a tile coord and zoom level ([@tschaub](https://github.com/tschaub))
 * [#12023](https://github.com/openlayers/openlayers/pull/12023) - Avoid collisions between user variables and internal names in WebGL shaders ([@tschaub](https://github.com/tschaub))
 * [#12027](https://github.com/openlayers/openlayers/pull/12027) - Update / fix links to external ressources ([@MoonE](https://github.com/MoonE))
 * [#11996](https://github.com/openlayers/openlayers/pull/11996) - Update links to external resources ([@MoonE](https://github.com/MoonE))
 * [#12025](https://github.com/openlayers/openlayers/pull/12025) - Remove watch option from webpack serve script ([@fredj](https://github.com/fredj))
 * [#12021](https://github.com/openlayers/openlayers/pull/12021) - Allow source projection to be set after construction ([@tschaub](https://github.com/tschaub))
 * [#12022](https://github.com/openlayers/openlayers/pull/12022) - Throw when WebGL style parsing encounters an unexpected type ([@tschaub](https://github.com/tschaub))
 * [#12020](https://github.com/openlayers/openlayers/pull/12020) - Fix WebGL buffer deletion ([@tschaub](https://github.com/tschaub))
 * [#12018](https://github.com/openlayers/openlayers/pull/12018) - Only render vector tile image when needed ([@ahocevar](https://github.com/ahocevar))
 * [#12019](https://github.com/openlayers/openlayers/pull/12019) - Always use same order for renderedTiles ([@ahocevar](https://github.com/ahocevar))
 * [#12012](https://github.com/openlayers/openlayers/pull/12012) - Fix documentation for account parameter in ol/source/CartoDB ([@geraldo](https://github.com/geraldo))
 * [#11995](https://github.com/openlayers/openlayers/pull/11995) - Fix hitdetect inaccuracy for VectorLayer's getFeatures ([@MoonE](https://github.com/MoonE))
 * [#11990](https://github.com/openlayers/openlayers/pull/11990) - Remove renderMode: 'image' for vector tile layers ([@ahocevar](https://github.com/ahocevar))
 * [#12007](https://github.com/openlayers/openlayers/pull/12007) - Report all features being modified ([@ahocevar](https://github.com/ahocevar))
 * [#11991](https://github.com/openlayers/openlayers/pull/11991) - Fix some typings in format and format/WKT ([@simonseyock](https://github.com/simonseyock))
 * [#11992](https://github.com/openlayers/openlayers/pull/11992) - Improve measure example ux ([@MoonE](https://github.com/MoonE))
 * [#11974](https://github.com/openlayers/openlayers/pull/11974) - Fix polyfill inconsistencies ([@mike-000](https://github.com/mike-000))
 * [#11987](https://github.com/openlayers/openlayers/pull/11987) - Respect opacity for vector instructions ([@ahocevar](https://github.com/ahocevar))
 * [#11989](https://github.com/openlayers/openlayers/pull/11989) - Correct pixel ratio descriptions ([@mike-000](https://github.com/mike-000))
 * [#11988](https://github.com/openlayers/openlayers/pull/11988) - Warn when map container's width or height are zero ([@ahocevar](https://github.com/ahocevar))
 * [#11978](https://github.com/openlayers/openlayers/pull/11978) - Add snapToPointer option ([@ahocevar](https://github.com/ahocevar))
 * [#11981](https://github.com/openlayers/openlayers/pull/11981) - Add descriptions for properties. ([@simonseyock](https://github.com/simonseyock))
 * [#11979](https://github.com/openlayers/openlayers/pull/11979) - Jsdoc types syntax ([@simonseyock](https://github.com/simonseyock))
 * [#11977](https://github.com/openlayers/openlayers/pull/11977) - More consistent JSDoc syntax ([@tschaub](https://github.com/tschaub))
 * [#11975](https://github.com/openlayers/openlayers/pull/11975) - jsdoc linting ([@simonseyock](https://github.com/simonseyock))
 * [#11967](https://github.com/openlayers/openlayers/pull/11967) - Simplify popup positioning in Icon Scale example ([@mike-000](https://github.com/mike-000))
 * [#11954](https://github.com/openlayers/openlayers/pull/11954) - Simplify icon example ([@ahocevar](https://github.com/ahocevar))
 * [#11965](https://github.com/openlayers/openlayers/pull/11965) - Handle view rotation in d3 Integration example ([@mike-000](https://github.com/mike-000))
 * [#11950](https://github.com/openlayers/openlayers/pull/11950) - Make polygons in the GeoJSON example comply to GeoJSON specification ([@mike-000](https://github.com/mike-000))
 * [#11948](https://github.com/openlayers/openlayers/pull/11948) - Improve layer typings ([@simonseyock](https://github.com/simonseyock))
 * [#11955](https://github.com/openlayers/openlayers/pull/11955) - Fix URLs in ol/source/CartoDB pointing to CartoDB API docs ([@geraldo](https://github.com/geraldo))
 * [#11947](https://github.com/openlayers/openlayers/pull/11947) - Demonstrates how to get the coordinates been clustered. ([@yukihiratype2](https://github.com/yukihiratype2))
 * [#11938](https://github.com/openlayers/openlayers/pull/11938) - Take view padding into account for calculateExtent() ([@ahocevar](https://github.com/ahocevar))
 * [#11941](https://github.com/openlayers/openlayers/pull/11941) - Fix loading flag for vector loading strategies ([@ahocevar](https://github.com/ahocevar))
 * [#11925](https://github.com/openlayers/openlayers/pull/11925) - Mention unit of radius for Polygon.circular() ([@kannes](https://github.com/kannes))
 * [#11914](https://github.com/openlayers/openlayers/pull/11914) - Fix image with text decluttering ([@ahocevar](https://github.com/ahocevar))
 * [#11911](https://github.com/openlayers/openlayers/pull/11911) - Do not clip declutter executor groups ([@ahocevar](https://github.com/ahocevar))
 * [#11856](https://github.com/openlayers/openlayers/pull/11856) - Use tilegrid extent as default attributionExtent for TileJSON ([@mike-000](https://github.com/mike-000))
 * [#11900](https://github.com/openlayers/openlayers/pull/11900) - Update pratique key to choisirgeoportail in the IGN WMTS example ([@mike-000](https://github.com/mike-000))
 * [#11913](https://github.com/openlayers/openlayers/pull/11913) - Handle null geometry in TopoJSON ([@mike-000](https://github.com/mike-000))
 * [#11893](https://github.com/openlayers/openlayers/pull/11893) - Pass the renderer function to the cloned style ([@mjjurkoic](https://github.com/mjjurkoic))
 * [#11901](https://github.com/openlayers/openlayers/pull/11901) - Fix handling of VectorTile renderBuffer ([@ahocevar](https://github.com/ahocevar))
 * [#11899](https://github.com/openlayers/openlayers/pull/11899) - Update HERE Map Tile API example to use API key ([@mike-000](https://github.com/mike-000))
 * [#11890](https://github.com/openlayers/openlayers/pull/11890) - Fix WFS writeFilter ([@walkermatt](https://github.com/walkermatt))
 * [#11892](https://github.com/openlayers/openlayers/pull/11892) - Restore stopClick functionality ([@ahocevar](https://github.com/ahocevar))
 * [#11882](https://github.com/openlayers/openlayers/pull/11882) - Improved documentation for feature load events. ([@simonseyock](https://github.com/simonseyock))
 * [#11886](https://github.com/openlayers/openlayers/pull/11886) - Throw an error if shaders fail to compile or program fails to link ([@tschaub](https://github.com/tschaub))
 * [#11874](https://github.com/openlayers/openlayers/pull/11874) - Hit lines even if they are dashed ([@tschaub](https://github.com/tschaub))
 * [#11873](https://github.com/openlayers/openlayers/pull/11873) - Update Mapbox-gl Layer example to mapbox-gl-js version 1.13.0 and add note about why an old version is used ([@mike-000](https://github.com/mike-000))
 * [#11865](https://github.com/openlayers/openlayers/pull/11865) - Use ol/array#includes instead of Array.prototype.includes() ([@mike-000](https://github.com/mike-000))
 * [#11872](https://github.com/openlayers/openlayers/pull/11872) - Legacy build for legacy browsers ([@ahocevar](https://github.com/ahocevar))
 * [#11871](https://github.com/openlayers/openlayers/pull/11871) - Fix examples and build for ie11 ([@MoonE](https://github.com/MoonE))


<details>
  <summary>Dependency Updates</summary>

 * [#12470](https://github.com/openlayers/openlayers/pull/12470) - Bump loglevelnext from 4.0.1 to 5.0.5 ([@openlayers](https://github.com/openlayers))
 * [#12472](https://github.com/openlayers/openlayers/pull/12472) - Bump eslint from 7.29.0 to 7.30.0 ([@openlayers](https://github.com/openlayers))
 * [#12471](https://github.com/openlayers/openlayers/pull/12471) - Bump coveralls from 3.1.0 to 3.1.1 ([@openlayers](https://github.com/openlayers))
 * [#12473](https://github.com/openlayers/openlayers/pull/12473) - Bump mocha from 9.0.1 to 9.0.2 ([@openlayers](https://github.com/openlayers))
 * [#12476](https://github.com/openlayers/openlayers/pull/12476) - Bump @types/topojson-specification from 1.0.1 to 1.0.2 ([@openlayers](https://github.com/openlayers))
 * [#12469](https://github.com/openlayers/openlayers/pull/12469) - Bump puppeteer from 10.0.0 to 10.1.0 ([@openlayers](https://github.com/openlayers))
 * [#12474](https://github.com/openlayers/openlayers/pull/12474) - Bump typescript from 4.3.4 to 4.3.5 ([@openlayers](https://github.com/openlayers))
 * [#12475](https://github.com/openlayers/openlayers/pull/12475) - Bump rollup from 2.52.3 to 2.52.7 ([@openlayers](https://github.com/openlayers))
 * [#12468](https://github.com/openlayers/openlayers/pull/12468) - Bump webpack from 5.40.0 to 5.42.0 ([@openlayers](https://github.com/openlayers))
 * [#12443](https://github.com/openlayers/openlayers/pull/12443) - Bump marked from 2.1.2 to 2.1.3 ([@openlayers](https://github.com/openlayers))
 * [#12444](https://github.com/openlayers/openlayers/pull/12444) - Bump terser-webpack-plugin from 5.1.3 to 5.1.4 ([@openlayers](https://github.com/openlayers))
 * [#12445](https://github.com/openlayers/openlayers/pull/12445) - Bump @babel/preset-env from 7.14.5 to 7.14.7 ([@openlayers](https://github.com/openlayers))
 * [#12446](https://github.com/openlayers/openlayers/pull/12446) - Bump rollup from 2.52.2 to 2.52.3 ([@openlayers](https://github.com/openlayers))
 * [#12447](https://github.com/openlayers/openlayers/pull/12447) - Bump eslint-config-openlayers from 15.0.0 to 15.1.0 ([@openlayers](https://github.com/openlayers))
 * [#12448](https://github.com/openlayers/openlayers/pull/12448) - Bump copy-webpack-plugin from 9.0.0 to 9.0.1 ([@openlayers](https://github.com/openlayers))
 * [#12449](https://github.com/openlayers/openlayers/pull/12449) - Bump @babel/eslint-parser from 7.14.5 to 7.14.7 ([@openlayers](https://github.com/openlayers))
 * [#12423](https://github.com/openlayers/openlayers/pull/12423) - Bump globby from 11.0.3 to 11.0.4 ([@openlayers](https://github.com/openlayers))
 * [#12435](https://github.com/openlayers/openlayers/pull/12435) - Bump marked from 2.0.7 to 2.1.2 ([@openlayers](https://github.com/openlayers))
 * [#12426](https://github.com/openlayers/openlayers/pull/12426) - Bump @babel/core from 7.14.5 to 7.14.6 ([@openlayers](https://github.com/openlayers))
 * [#12427](https://github.com/openlayers/openlayers/pull/12427) - Bump typescript from 4.3.2 to 4.3.4 ([@openlayers](https://github.com/openlayers))
 * [#12421](https://github.com/openlayers/openlayers/pull/12421) - Bump eslint from 7.28.0 to 7.29.0 ([@openlayers](https://github.com/openlayers))
 * [#12420](https://github.com/openlayers/openlayers/pull/12420) - Bump mocha from 9.0.0 to 9.0.1 ([@openlayers](https://github.com/openlayers))
 * [#12425](https://github.com/openlayers/openlayers/pull/12425) - Bump rollup from 2.51.2 to 2.52.2 ([@openlayers](https://github.com/openlayers))
 * [#12428](https://github.com/openlayers/openlayers/pull/12428) - Bump proj4 from 2.7.2 to 2.7.4 ([@openlayers](https://github.com/openlayers))
 * [#12433](https://github.com/openlayers/openlayers/pull/12433) - Bump webpack from 5.38.1 to 5.40.0 ([@openlayers](https://github.com/openlayers))
 * [#12397](https://github.com/openlayers/openlayers/pull/12397) - Bump @babel/eslint-parser from 7.14.4 to 7.14.5 ([@openlayers](https://github.com/openlayers))
 * [#12398](https://github.com/openlayers/openlayers/pull/12398) - Bump karma from 6.3.3 to 6.3.4 ([@openlayers](https://github.com/openlayers))
 * [#12400](https://github.com/openlayers/openlayers/pull/12400) - Bump webpack-cli from 4.7.0 to 4.7.2 ([@openlayers](https://github.com/openlayers))
 * [#12401](https://github.com/openlayers/openlayers/pull/12401) - Bump @babel/preset-env from 7.14.4 to 7.14.5 ([@openlayers](https://github.com/openlayers))
 * [#12402](https://github.com/openlayers/openlayers/pull/12402) - Bump rollup from 2.51.0 to 2.51.2 ([@openlayers](https://github.com/openlayers))
 * [#12403](https://github.com/openlayers/openlayers/pull/12403) - Bump @babel/core from 7.14.3 to 7.14.5 ([@openlayers](https://github.com/openlayers))
 * [#12399](https://github.com/openlayers/openlayers/pull/12399) - Bump mocha from 8.4.0 to 9.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12386](https://github.com/openlayers/openlayers/pull/12386) - Bump rollup from 2.50.5 to 2.51.0 ([@openlayers](https://github.com/openlayers))
 * [#12384](https://github.com/openlayers/openlayers/pull/12384) - Bump karma-firefox-launcher from 2.1.0 to 2.1.1 ([@openlayers](https://github.com/openlayers))
 * [#12385](https://github.com/openlayers/openlayers/pull/12385) - Bump marked from 2.0.6 to 2.0.7 ([@openlayers](https://github.com/openlayers))
 * [#12383](https://github.com/openlayers/openlayers/pull/12383) - Bump webpack-dev-middleware from 4.3.0 to 5.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12379](https://github.com/openlayers/openlayers/pull/12379) - Bump karma from 6.3.2 to 6.3.3 ([@openlayers](https://github.com/openlayers))
 * [#12381](https://github.com/openlayers/openlayers/pull/12381) - Bump terser-webpack-plugin from 5.1.2 to 5.1.3 ([@openlayers](https://github.com/openlayers))
 * [#12382](https://github.com/openlayers/openlayers/pull/12382) - Bump eslint from 7.27.0 to 7.28.0 ([@openlayers](https://github.com/openlayers))
 * [#12380](https://github.com/openlayers/openlayers/pull/12380) - Bump puppeteer from 9.1.1 to 10.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12368](https://github.com/openlayers/openlayers/pull/12368) - Bump typescript from 4.2.4 to 4.3.2 ([@openlayers](https://github.com/openlayers))
 * [#12365](https://github.com/openlayers/openlayers/pull/12365) - Bump rollup from 2.49.0 to 2.50.5 ([@openlayers](https://github.com/openlayers))
 * [#12371](https://github.com/openlayers/openlayers/pull/12371) - Bump marked from 2.0.5 to 2.0.6 ([@openlayers](https://github.com/openlayers))
 * [#12366](https://github.com/openlayers/openlayers/pull/12366) - Bump @babel/eslint-parser from 7.14.3 to 7.14.4 ([@openlayers](https://github.com/openlayers))
 * [#12367](https://github.com/openlayers/openlayers/pull/12367) - Bump @babel/preset-env from 7.14.2 to 7.14.4 ([@openlayers](https://github.com/openlayers))
 * [#12369](https://github.com/openlayers/openlayers/pull/12369) - Bump webpack from 5.37.1 to 5.38.1 ([@openlayers](https://github.com/openlayers))
 * [#12370](https://github.com/openlayers/openlayers/pull/12370) - Bump webpack-sources from 2.2.0 to 2.3.0 ([@openlayers](https://github.com/openlayers))
 * [#12372](https://github.com/openlayers/openlayers/pull/12372) - Bump sinon from 10.0.0 to 11.1.1 ([@openlayers](https://github.com/openlayers))
 * [#12341](https://github.com/openlayers/openlayers/pull/12341) - Bump webpack-dev-middleware from 4.2.0 to 4.3.0 ([@openlayers](https://github.com/openlayers))
 * [#12321](https://github.com/openlayers/openlayers/pull/12321) - Bump webpack-dev-server from 4.0.0-beta.2 to 4.0.0-beta.3 ([@openlayers](https://github.com/openlayers))
 * [#12345](https://github.com/openlayers/openlayers/pull/12345) - Bump eslint from 7.26.0 to 7.27.0 ([@openlayers](https://github.com/openlayers))
 * [#12342](https://github.com/openlayers/openlayers/pull/12342) - Bump copy-webpack-plugin from 8.1.1 to 9.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12343](https://github.com/openlayers/openlayers/pull/12343) - Bump rollup from 2.48.0 to 2.49.0 ([@openlayers](https://github.com/openlayers))
 * [#12344](https://github.com/openlayers/openlayers/pull/12344) - Bump marked from 2.0.3 to 2.0.5 ([@openlayers](https://github.com/openlayers))
 * [#12346](https://github.com/openlayers/openlayers/pull/12346) - Bump @babel/core from 7.14.2 to 7.14.3 ([@openlayers](https://github.com/openlayers))
 * [#12347](https://github.com/openlayers/openlayers/pull/12347) - Bump @babel/eslint-parser from 7.14.2 to 7.14.3 ([@openlayers](https://github.com/openlayers))
 * [#12348](https://github.com/openlayers/openlayers/pull/12348) - Bump webpack from 5.37.0 to 5.37.1 ([@openlayers](https://github.com/openlayers))
 * [#12326](https://github.com/openlayers/openlayers/pull/12326) - Bump webpack from 5.36.2 to 5.37.0 ([@openlayers](https://github.com/openlayers))
 * [#12323](https://github.com/openlayers/openlayers/pull/12323) - Bump @babel/core from 7.14.0 to 7.14.2 ([@openlayers](https://github.com/openlayers))
 * [#12322](https://github.com/openlayers/openlayers/pull/12322) - Bump jsdoc from 3.6.6 to 3.6.7 ([@openlayers](https://github.com/openlayers))
 * [#12324](https://github.com/openlayers/openlayers/pull/12324) - Bump rollup from 2.47.0 to 2.48.0 ([@openlayers](https://github.com/openlayers))
 * [#12325](https://github.com/openlayers/openlayers/pull/12325) - Bump terser-webpack-plugin from 5.1.1 to 5.1.2 ([@openlayers](https://github.com/openlayers))
 * [#12327](https://github.com/openlayers/openlayers/pull/12327) - Bump @babel/eslint-parser from 7.13.14 to 7.14.2 ([@openlayers](https://github.com/openlayers))
 * [#12328](https://github.com/openlayers/openlayers/pull/12328) - Bump @babel/preset-env from 7.14.0 to 7.14.2 ([@openlayers](https://github.com/openlayers))
 * [#12320](https://github.com/openlayers/openlayers/pull/12320) - Bump webpack-dev-middleware from 4.1.0 to 4.2.0 ([@openlayers](https://github.com/openlayers))
 * [#12288](https://github.com/openlayers/openlayers/pull/12288) - Bump @rollup/plugin-node-resolve from 11.2.1 to 13.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12286](https://github.com/openlayers/openlayers/pull/12286) - Bump fs-extra from 9.1.0 to 10.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12287](https://github.com/openlayers/openlayers/pull/12287) - Bump webpack-cli from 4.6.0 to 4.7.0 ([@openlayers](https://github.com/openlayers))
 * [#12293](https://github.com/openlayers/openlayers/pull/12293) - Bump yargs from 17.0.0 to 17.0.1 ([@openlayers](https://github.com/openlayers))
 * [#12289](https://github.com/openlayers/openlayers/pull/12289) - Bump @rollup/plugin-commonjs from 18.0.0 to 19.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12290](https://github.com/openlayers/openlayers/pull/12290) - Bump rollup from 2.46.0 to 2.47.0 ([@openlayers](https://github.com/openlayers))
 * [#12291](https://github.com/openlayers/openlayers/pull/12291) - Bump puppeteer from 9.0.0 to 9.1.1 ([@openlayers](https://github.com/openlayers))
 * [#12292](https://github.com/openlayers/openlayers/pull/12292) - Bump eslint from 7.25.0 to 7.26.0 ([@openlayers](https://github.com/openlayers))
 * [#12294](https://github.com/openlayers/openlayers/pull/12294) - Bump mocha from 8.3.2 to 8.4.0 ([@openlayers](https://github.com/openlayers))
 * [#12295](https://github.com/openlayers/openlayers/pull/12295) - Bump glob from 7.1.6 to 7.1.7 ([@openlayers](https://github.com/openlayers))
 * [#12269](https://github.com/openlayers/openlayers/pull/12269) - Bump webpack from 5.36.1 to 5.36.2 ([@openlayers](https://github.com/openlayers))
 * [#12268](https://github.com/openlayers/openlayers/pull/12268) - Bump rollup from 2.45.2 to 2.46.0 ([@openlayers](https://github.com/openlayers))
 * [#12270](https://github.com/openlayers/openlayers/pull/12270) - Bump @babel/preset-env from 7.13.15 to 7.14.0 ([@openlayers](https://github.com/openlayers))
 * [#12271](https://github.com/openlayers/openlayers/pull/12271) - Bump yargs from 16.2.0 to 17.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12272](https://github.com/openlayers/openlayers/pull/12272) - Bump @babel/core from 7.13.16 to 7.14.0 ([@openlayers](https://github.com/openlayers))
 * [#12256](https://github.com/openlayers/openlayers/pull/12256) - Bump clean-css-cli from 5.2.2 to 5.3.0 ([@openlayers](https://github.com/openlayers))
 * [#12255](https://github.com/openlayers/openlayers/pull/12255) - Bump webpack from 5.35.1 to 5.36.1 ([@openlayers](https://github.com/openlayers))
 * [#12254](https://github.com/openlayers/openlayers/pull/12254) - Upgrade to GitHub-native Dependabot ([@openlayers](https://github.com/openlayers))
 * [#12245](https://github.com/openlayers/openlayers/pull/12245) - Bump webpack from 5.33.2 to 5.35.1 ([@openlayers](https://github.com/openlayers))
 * [#12244](https://github.com/openlayers/openlayers/pull/12244) - Bump @babel/core from 7.13.15 to 7.13.16 ([@openlayers](https://github.com/openlayers))
 * [#12243](https://github.com/openlayers/openlayers/pull/12243) - Bump puppeteer from 8.0.0 to 9.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12242](https://github.com/openlayers/openlayers/pull/12242) - Bump eslint from 7.24.0 to 7.25.0 ([@openlayers](https://github.com/openlayers))
 * [#12206](https://github.com/openlayers/openlayers/pull/12206) - Bump rollup from 2.44.0 to 2.45.1 ([@openlayers](https://github.com/openlayers))
 * [#12205](https://github.com/openlayers/openlayers/pull/12205) - Bump typescript from 4.2.3 to 4.2.4 ([@openlayers](https://github.com/openlayers))
 * [#12204](https://github.com/openlayers/openlayers/pull/12204) - Bump @babel/preset-env from 7.13.12 to 7.13.15 ([@openlayers](https://github.com/openlayers))
 * [#12203](https://github.com/openlayers/openlayers/pull/12203) - Bump marked from 2.0.1 to 2.0.3 ([@openlayers](https://github.com/openlayers))
 * [#12202](https://github.com/openlayers/openlayers/pull/12202) - Bump copy-webpack-plugin from 8.1.0 to 8.1.1 ([@openlayers](https://github.com/openlayers))
 * [#12201](https://github.com/openlayers/openlayers/pull/12201) - Bump @babel/core from 7.13.14 to 7.13.15 ([@openlayers](https://github.com/openlayers))
 * [#12200](https://github.com/openlayers/openlayers/pull/12200) - Bump webpack from 5.30.0 to 5.31.2 ([@openlayers](https://github.com/openlayers))
 * [#12199](https://github.com/openlayers/openlayers/pull/12199) - Bump eslint from 7.23.0 to 7.24.0 ([@openlayers](https://github.com/openlayers))
 * [#12184](https://github.com/openlayers/openlayers/pull/12184) - Bump karma from 6.3.1 to 6.3.2 ([@openlayers](https://github.com/openlayers))
 * [#12183](https://github.com/openlayers/openlayers/pull/12183) - Bump @babel/core from 7.13.13 to 7.13.14 ([@openlayers](https://github.com/openlayers))
 * [#12182](https://github.com/openlayers/openlayers/pull/12182) - Bump copy-webpack-plugin from 8.0.0 to 8.1.0 ([@openlayers](https://github.com/openlayers))
 * [#12155](https://github.com/openlayers/openlayers/pull/12155) - Bump eslint from 7.22.0 to 7.23.0 ([@openlayers](https://github.com/openlayers))
 * [#12158](https://github.com/openlayers/openlayers/pull/12158) - Bump @babel/preset-env from 7.13.10 to 7.13.12 ([@openlayers](https://github.com/openlayers))
 * [#12156](https://github.com/openlayers/openlayers/pull/12156) - Bump @rollup/plugin-node-resolve from 11.2.0 to 11.2.1 ([@openlayers](https://github.com/openlayers))
 * [#12159](https://github.com/openlayers/openlayers/pull/12159) - Bump @babel/core from 7.13.10 to 7.13.13 ([@openlayers](https://github.com/openlayers))
 * [#12174](https://github.com/openlayers/openlayers/pull/12174) - Bump rollup from 2.42.3 to 2.44.0 ([@openlayers](https://github.com/openlayers))
 * [#12157](https://github.com/openlayers/openlayers/pull/12157) - Bump karma from 6.2.0 to 6.3.1 ([@openlayers](https://github.com/openlayers))
 * [#12173](https://github.com/openlayers/openlayers/pull/12173) - Bump webpack from 5.27.2 to 5.30.0 ([@openlayers](https://github.com/openlayers))
 * [#12153](https://github.com/openlayers/openlayers/pull/12153) - Bump webpack-cli from 4.5.0 to 4.6.0 ([@openlayers](https://github.com/openlayers))
 * [#12151](https://github.com/openlayers/openlayers/pull/12151) - Bump @rollup/plugin-commonjs from 17.1.0 to 18.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12150](https://github.com/openlayers/openlayers/pull/12150) - Bump sinon from 9.2.4 to 10.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12130](https://github.com/openlayers/openlayers/pull/12130) - Bump clean-css-cli from 5.2.1 to 5.2.2 ([@openlayers](https://github.com/openlayers))
 * [#12131](https://github.com/openlayers/openlayers/pull/12131) - Bump rollup from 2.41.2 to 2.42.2 ([@openlayers](https://github.com/openlayers))
 * [#12108](https://github.com/openlayers/openlayers/pull/12108) - Bump @babel/preset-env from 7.13.9 to 7.13.10 ([@openlayers](https://github.com/openlayers))
 * [#12109](https://github.com/openlayers/openlayers/pull/12109) - Bump mocha from 8.3.1 to 8.3.2 ([@openlayers](https://github.com/openlayers))
 * [#12110](https://github.com/openlayers/openlayers/pull/12110) - Bump rollup from 2.40.0 to 2.41.2 ([@openlayers](https://github.com/openlayers))
 * [#12111](https://github.com/openlayers/openlayers/pull/12111) - Bump @babel/core from 7.13.8 to 7.13.10 ([@openlayers](https://github.com/openlayers))
 * [#12107](https://github.com/openlayers/openlayers/pull/12107) - Bump eslint from 7.21.0 to 7.22.0 ([@openlayers](https://github.com/openlayers))
 * [#12112](https://github.com/openlayers/openlayers/pull/12112) - Bump karma from 6.1.1 to 6.2.0 ([@openlayers](https://github.com/openlayers))
 * [#12099](https://github.com/openlayers/openlayers/pull/12099) - [Security] Bump elliptic from 6.5.3 to 6.5.4 ([@openlayers](https://github.com/openlayers))
 * [#12097](https://github.com/openlayers/openlayers/pull/12097) - Bump ol-mapbox-style from 6.3.1 to 6.3.2 ([@openlayers](https://github.com/openlayers))
 * [#12096](https://github.com/openlayers/openlayers/pull/12096) - Bump @babel/preset-env from 7.13.8 to 7.13.9 ([@openlayers](https://github.com/openlayers))
 * [#12095](https://github.com/openlayers/openlayers/pull/12095) - Bump clean-css-cli from 5.2.0 to 5.2.1 ([@openlayers](https://github.com/openlayers))
 * [#12094](https://github.com/openlayers/openlayers/pull/12094) - Bump jquery from 3.5.1 to 3.6.0 ([@openlayers](https://github.com/openlayers))
 * [#12093](https://github.com/openlayers/openlayers/pull/12093) - Bump typescript from 4.2.2 to 4.2.3 ([@openlayers](https://github.com/openlayers))
 * [#12092](https://github.com/openlayers/openlayers/pull/12092) - Bump proj4 from 2.7.0 to 2.7.2 ([@openlayers](https://github.com/openlayers))
 * [#12091](https://github.com/openlayers/openlayers/pull/12091) - Bump mocha from 8.3.0 to 8.3.1 ([@openlayers](https://github.com/openlayers))
 * [#12077](https://github.com/openlayers/openlayers/pull/12077) - Bump rollup from 2.39.0 to 2.40.0 ([@openlayers](https://github.com/openlayers))
 * [#12076](https://github.com/openlayers/openlayers/pull/12076) - Bump typescript from 4.1.5 to 4.2.2 ([@openlayers](https://github.com/openlayers))
 * [#12075](https://github.com/openlayers/openlayers/pull/12075) - Bump eslint from 7.20.0 to 7.21.0 ([@openlayers](https://github.com/openlayers))
 * [#12074](https://github.com/openlayers/openlayers/pull/12074) - Bump marked from 2.0.0 to 2.0.1 ([@openlayers](https://github.com/openlayers))
 * [#12073](https://github.com/openlayers/openlayers/pull/12073) - Bump @babel/preset-env from 7.12.17 to 7.13.8 ([@openlayers](https://github.com/openlayers))
 * [#12072](https://github.com/openlayers/openlayers/pull/12072) - Bump puppeteer from 7.1.0 to 8.0.0 ([@openlayers](https://github.com/openlayers))
 * [#12071](https://github.com/openlayers/openlayers/pull/12071) - Bump @babel/core from 7.12.17 to 7.13.8 ([@openlayers](https://github.com/openlayers))
 * [#12056](https://github.com/openlayers/openlayers/pull/12056) - Bump @babel/preset-env from 7.12.16 to 7.12.17 ([@openlayers](https://github.com/openlayers))
 * [#12055](https://github.com/openlayers/openlayers/pull/12055) - Bump handlebars from 4.7.6 to 4.7.7 ([@openlayers](https://github.com/openlayers))
 * [#12054](https://github.com/openlayers/openlayers/pull/12054) - Bump @babel/core from 7.12.16 to 7.12.17 ([@openlayers](https://github.com/openlayers))
 * [#12053](https://github.com/openlayers/openlayers/pull/12053) - Bump clean-css-cli from 5.1.0 to 5.2.0 ([@openlayers](https://github.com/openlayers))
 * [#12036](https://github.com/openlayers/openlayers/pull/12036) - Bump clean-css-cli from 4.3.0 to 5.1.0 ([@openlayers](https://github.com/openlayers))
 * [#12035](https://github.com/openlayers/openlayers/pull/12035) - Bump karma from 6.1.0 to 6.1.1 ([@openlayers](https://github.com/openlayers))
 * [#12031](https://github.com/openlayers/openlayers/pull/12031) - Bump puppeteer from 7.0.1 to 7.1.0 ([@openlayers](https://github.com/openlayers))
 * [#12033](https://github.com/openlayers/openlayers/pull/12033) - Bump typescript from 4.1.3 to 4.1.5 ([@openlayers](https://github.com/openlayers))
 * [#12030](https://github.com/openlayers/openlayers/pull/12030) - Bump worker-loader from 3.0.7 to 3.0.8 ([@openlayers](https://github.com/openlayers))
 * [#12032](https://github.com/openlayers/openlayers/pull/12032) - Bump rollup from 2.38.5 to 2.39.0 ([@openlayers](https://github.com/openlayers))
 * [#12034](https://github.com/openlayers/openlayers/pull/12034) - Bump eslint from 7.19.0 to 7.20.0 ([@openlayers](https://github.com/openlayers))
 * [#12037](https://github.com/openlayers/openlayers/pull/12037) - Bump mocha from 8.2.1 to 8.3.0 ([@openlayers](https://github.com/openlayers))
 * [#12038](https://github.com/openlayers/openlayers/pull/12038) - Bump @babel/core from 7.12.13 to 7.12.16 ([@openlayers](https://github.com/openlayers))
 * [#12039](https://github.com/openlayers/openlayers/pull/12039) - Bump @babel/preset-env from 7.12.13 to 7.12.16 ([@openlayers](https://github.com/openlayers))
 * [#12004](https://github.com/openlayers/openlayers/pull/12004) - Bump rollup from 2.38.3 to 2.38.5 ([@openlayers](https://github.com/openlayers))
 * [#12001](https://github.com/openlayers/openlayers/pull/12001) - Bump karma from 6.0.3 to 6.1.0 ([@openlayers](https://github.com/openlayers))
 * [#11999](https://github.com/openlayers/openlayers/pull/11999) - Bump @babel/preset-env from 7.12.11 to 7.12.13 ([@openlayers](https://github.com/openlayers))
 * [#12000](https://github.com/openlayers/openlayers/pull/12000) - Bump @babel/core from 7.12.10 to 7.12.13 ([@openlayers](https://github.com/openlayers))
 * [#12003](https://github.com/openlayers/openlayers/pull/12003) - Bump puppeteer from 5.5.0 to 7.0.1 ([@openlayers](https://github.com/openlayers))
 * [#12005](https://github.com/openlayers/openlayers/pull/12005) - Bump webpack-cli from 4.4.0 to 4.5.0 ([@openlayers](https://github.com/openlayers))
 * [#12002](https://github.com/openlayers/openlayers/pull/12002) - [Security] Bump marked from 1.2.8 to 2.0.0 ([@openlayers](https://github.com/openlayers))
 * [#11971](https://github.com/openlayers/openlayers/pull/11971) - Bump marked from 1.2.7 to 1.2.8 ([@openlayers](https://github.com/openlayers))
 * [#11970](https://github.com/openlayers/openlayers/pull/11970) - Bump eslint from 7.18.0 to 7.19.0 ([@openlayers](https://github.com/openlayers))
 * [#11969](https://github.com/openlayers/openlayers/pull/11969) - Bump rollup from 2.38.0 to 2.38.3 ([@openlayers](https://github.com/openlayers))
 * [#11968](https://github.com/openlayers/openlayers/pull/11968) - Bump karma from 6.0.1 to 6.0.3 ([@openlayers](https://github.com/openlayers))
 * [#11943](https://github.com/openlayers/openlayers/pull/11943) - Bump fs-extra from 9.0.1 to 9.1.0 ([@openlayers](https://github.com/openlayers))
 * [#11944](https://github.com/openlayers/openlayers/pull/11944) - Bump webpack-cli from 4.3.1 to 4.4.0 ([@openlayers](https://github.com/openlayers))
 * [#11945](https://github.com/openlayers/openlayers/pull/11945) - Bump sinon from 9.2.3 to 9.2.4 ([@openlayers](https://github.com/openlayers))
 * [#11942](https://github.com/openlayers/openlayers/pull/11942) - Bump rollup from 2.36.2 to 2.38.0 ([@openlayers](https://github.com/openlayers))
 * [#11933](https://github.com/openlayers/openlayers/pull/11933) - Bump karma from 5.2.3 to 6.0.1 ([@openlayers](https://github.com/openlayers))
 * [#11930](https://github.com/openlayers/openlayers/pull/11930) - [Security] Bump socket.io from 2.3.0 to 2.4.1 ([@openlayers](https://github.com/openlayers))
 * [#11919](https://github.com/openlayers/openlayers/pull/11919) - Bump webpack-dev-server from 3.11.1 to 3.11.2 ([@openlayers](https://github.com/openlayers))
 * [#11922](https://github.com/openlayers/openlayers/pull/11922) - Bump eslint from 7.17.0 to 7.18.0 ([@openlayers](https://github.com/openlayers))
 * [#11921](https://github.com/openlayers/openlayers/pull/11921) - Bump rollup from 2.36.1 to 2.36.2 ([@openlayers](https://github.com/openlayers))
 * [#11918](https://github.com/openlayers/openlayers/pull/11918) - Bump webpack from 4.45.0 to 4.46.0 ([@openlayers](https://github.com/openlayers))
 * [#11915](https://github.com/openlayers/openlayers/pull/11915) - Bump webpack-dev-middleware from 4.0.2 to 4.1.0 ([@openlayers](https://github.com/openlayers))
 * [#11920](https://github.com/openlayers/openlayers/pull/11920) - Bump proj4 from 2.6.3 to 2.7.0 ([@openlayers](https://github.com/openlayers))
 * [#11916](https://github.com/openlayers/openlayers/pull/11916) - Bump ol-mapbox-style from 6.3.0 to 6.3.1 ([@openlayers](https://github.com/openlayers))
 * [#11905](https://github.com/openlayers/openlayers/pull/11905) - Bump globby from 11.0.1 to 11.0.2 ([@openlayers](https://github.com/openlayers))
 * [#11904](https://github.com/openlayers/openlayers/pull/11904) - Bump webpack from 4.44.2 to 4.45.0 ([@openlayers](https://github.com/openlayers))
 * [#11903](https://github.com/openlayers/openlayers/pull/11903) - Bump rollup from 2.35.1 to 2.36.1 ([@openlayers](https://github.com/openlayers))
 * [#11902](https://github.com/openlayers/openlayers/pull/11902) - Bump sinon from 9.2.2 to 9.2.3 ([@openlayers](https://github.com/openlayers))
 * [#11877](https://github.com/openlayers/openlayers/pull/11877) - Bump webpack-cli from 4.3.0 to 4.3.1 ([@openlayers](https://github.com/openlayers))
 * [#11878](https://github.com/openlayers/openlayers/pull/11878) - Bump webpack-dev-server from 3.11.0 to 3.11.1 ([@openlayers](https://github.com/openlayers))
 * [#11879](https://github.com/openlayers/openlayers/pull/11879) - Bump eslint from 7.16.0 to 7.17.0 ([@openlayers](https://github.com/openlayers))
 * [#11868](https://github.com/openlayers/openlayers/pull/11868) - Bump worker-loader from 3.0.6 to 3.0.7 ([@openlayers](https://github.com/openlayers))
 * [#11867](https://github.com/openlayers/openlayers/pull/11867) - Bump webpack-cli from 4.2.0 to 4.3.0 ([@openlayers](https://github.com/openlayers))


</details>
